.. _package-orm:

:mod:`orm` Package
==================

.. automodule:: odoo_rpc_client.orm
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`object` Module
--------------------

.. automodule:: odoo_rpc_client.orm.object
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cache` Module
--------------------

.. automodule:: odoo_rpc_client.orm.cache
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`record` Module
--------------------

.. automodule:: odoo_rpc_client.orm.record
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`service` Module
---------------------

.. automodule:: odoo_rpc_client.orm.service
    :members:
    :undoc-members:
    :show-inheritance:

